<?php
/**
* Plugin Name: ModelTheme Black Friday
* Plugin URI: https://modeltheme.com/
* Description: ModelTheme Black Friday Plugin for WooCommerce.
* Version: 2.0.3
* Author: 20script
* Author https://www.20script.ir
* Text Domain: mtbf
* Last Plugin Update: 10-NOV-2022
*/

register_activation_hook(__FILE__, 'createPageBlackFriday');

function createPageBlackFriday() {
	$check_page_exist = get_page_by_title('Black Friday', 'OBJECT', 'page');
	// Check if the page already exists
	if(empty($check_page_exist)) {
		$page_id = wp_insert_post(
			array(
				'comment_status' => 'close',
				'ping_status' => 'close',
				'post_author' => 1,
				'post_title' => ucwords(esc_html__('Black Friday', 'mtbf')),
				'post_name' => strtolower(str_replace(' ', '-', trim('black-friday'))),
				'post_status' => 'publish',
				'post_content' => '',
				'post_type' => 'page',
			)
		);

		if( !$page_id )
			wp_die('Error creating template page');
		else
			update_post_meta( $page_id, '_wp_page_template', 'mt-black-friday-template.php' );
	}
}

function mt_black_friday_template($template){
	global $wp_query;
	$theme_file = 'mt-black-friday-template.php';
	$exists_in_theme = locate_template( $theme_file, false );
	if (!$wp_query->is_page('black-friday')) {
		return $template;
	} else {
		if ( $exists_in_theme != '' ) {
			$template = $exists_in_theme;
		} else {
			if(file_exists(dirname( __FILE__ ) . '/mt-black-friday-template.php')) {
				$template = dirname( __FILE__ ) . '/mt-black-friday-template.php';
			}else {
				$template = dirname( __FILE__ ) . '/mt-black-friday-template.php';
			}
		}
	return $template;
	}
}
add_filter( 'template_include', 'mt_black_friday_template', 99 );

/**
 * Default function to render the Login/Register buttons, bundled with Vite.
 * @param $state string The state of the button (register/login/link/unlink)
 * @return string|void
 */
function mtbf_auth_app_instance($state) {
	require_once 'Vite.php';

    $vite = new MTBF_Auth_Vite();
    $nonce = is_user_logged_in() ? wp_create_nonce('wp_rest') : false;
    return '
    <div 
        id="black-friday"
        data-nonce="'.esc_attr( $nonce ).'"
        data-current-state="'.esc_attr( $state ).'"
		data-site-url="'.esc_attr( get_site_url() ).'"
        data-api-url="'.esc_attr( get_rest_url() ).'"
    >
        <noscript>'.esc_html__('You need javascript enabled to see this content', 'mtbf').'.</noscript>
    </div>
    '.$vite;
}
add_shortcode('template_shortcode','mtbf_auth_app_instance');

add_action("rest_api_init", function () {
	register_rest_route('mtbf', '/get-options', array(
		'methods' => 'GET',
		'callback' => 'mtbf_obtain_options',
		'permission_callback' => '__return_true',
	));
	register_rest_route('mtbf', '/get-categories', array(
		'methods' => 'GET',
		'callback' => 'mtbf_obtain_categories',
		'permission_callback' => '__return_true',
	));
	register_rest_route('mtbf', '/get-campaign-details', array(
		'methods' => 'GET',
		'callback' => 'mtbf_obtain_campaign_details',
		'permission_callback' => '__return_true',
	));
	register_rest_route('mtbf', '/get-currency-details', array(
		'methods' => 'GET',
		'callback' => 'mtbf_obtain_currency_details',
		'permission_callback' => '__return_true',
	));
	register_rest_route('mtbf', '/get-additional-products', array(
		'methods' => 'GET',
		'callback' => 'mtbf_obtain_additional_products',
		'permission_callback' => '__return_true',
	));
	register_rest_route('mtbf', '/get-hardcoded-strings', array(
		'methods' => 'GET',
		'callback' => 'mtbf_obtain_hardcoded_strings',
		'permission_callback' => '__return_true',
	));
});

function mtbf_obtain_currency_details() {
	$currency_details = array(
		'currency' => get_woocommerce_currency(),
		'currency_symbol' => get_woocommerce_currency_symbol(),
		'currency_position' => get_option('woocommerce_currency_pos', true),
		'currency_thousand_separator' => get_option('woocommerce_price_thousand_sep', true),
		'currency_decimals_separator' => get_option('woocommerce_price_decimal_sep', true),
		'currency_decimals_number' => get_option('woocommerce_price_num_decimals', true),
	);
	return $currency_details;
}

function mtbf_obtain_options() {
	$all_options = wp_load_alloptions();
	$result_options  = array();
	foreach ($all_options as $name => $value) {
		if (strpos($name, 'mtbf') !== false) {
			if ($name === 'mtbf_excluded_categories') {
				$unserializedValue = unserialize($value);
				$all_categories = get_terms( 
					'product_cat', 
					array( 
						'parent' => 0, 
						'orderby' => 'slug',
						'hide_empty' => 1,
					)
				);
				$excluded_categories = array();
				foreach ($all_categories as $category) {
					if (in_array($category->term_id, $unserializedValue)) {
						array_push($excluded_categories, $category);
					}
				}
				$result_options[$name] = $excluded_categories;
			} else {
				$result_options[$name] = $value;
			}
		}
	}
	$cart_url = wc_get_cart_url();
	$account_url = get_permalink( get_option('woocommerce_myaccount_page_id') );
	$result_options['cart_url'] = $cart_url;
	$result_options['account_url'] = $account_url;
	return $result_options;
}

function mtbf_obtain_categories() {
	$all_options = wp_load_alloptions();
	$result_categories  = array();
	foreach ($all_options as $name => $value) {
		if (strpos($name, 'mtbf') !== false) {
			if (is_serialized($value)) {
				$unserializedValue = unserialize($value);
				$all_categories = get_terms( 
					'product_cat', 
					array( 
						'parent' => 0, 
						'orderby' => 'slug',
						'hide_empty' => 1,
					)
				);
				foreach ($all_categories as $category) {
					if (!in_array($category->term_id, $unserializedValue)) {
						array_push($result_categories, $category);
					}
				}
			}
		}
	}
	return $result_categories;
}

function mtbf_obtain_campaign_details($request) {
	$campaign = $request->get_param("active-campaign");
	$campaign_details = array(
		'campaign_id' => $campaign,
		'campaign_title' => get_the_title($campaign),
		'campaign_datetime_start_date' => get_post_meta($campaign, 'mtbf_datetime_start_date', true),
		'campaign_datetime_start_time' => get_post_meta($campaign, 'mtbf_datetime_start_time', true),
		'campaign_datetime_end_date' => get_post_meta($campaign, 'mtbf_datetime_end_date', true),
		'campaign_datetime_end_time' => get_post_meta($campaign, 'mtbf_datetime_end_time', true),
		'campaign_header_logo' => get_post_meta($campaign, 'mtbf_header_logo', true),
		'campaign_header_background_color' => get_post_meta($campaign, 'mtbf_header_bg', true),
		'campaign_header_back_to_website_url' => get_post_meta($campaign, 'mtbf_header_back_to_website_url', true),
		'campaign_header_back_to_website_url_label' => get_post_meta($campaign, 'mtbf_header_back_to_website_url_label', true),
		'campaign_png_graphic' => get_post_meta($campaign, 'mtbf_png_graphic', true),
		'campaign_after_header_background' => get_post_meta($campaign, 'mtbf_after_header_bg', true),
		'campaign_body_background' => get_post_meta($campaign, 'mtbf_body_bg', true),
		'campaign_body_background_color' => get_post_meta($campaign, 'mtbf_body_bg_color', true),
		'campaign_button_color' => get_post_meta($campaign, 'mtbf_button_color', true),
		'campaign_button_color_hover' => get_post_meta($campaign, 'mtbf_button_color_hover', true),
		'campaign_product_button_border_radius' => get_post_meta($campaign, 'mtbf_product_button_border_radius', true),
		'campaign_archive_grid_prods_per_row' => get_post_meta($campaign, 'mtbf_archive_grid_prods_per_row', true),
		'campaign_archive_grid_prods_limit' => get_post_meta($campaign, 'mtbf_archive_grid_prods_limit', true),
		'campaign_extra_classes_to_hide' => get_post_meta($campaign, 'mtbf_extra_classes_to_hide', true),
		'campaign_sale_badge_text' => get_post_meta($campaign, 'mtbf_sale_badge_text', true),
		'campaign_sale_badge' => get_post_meta($campaign, 'mtbf_sale_badge_img', true),
		'campaign_sale_badge_image_width' => get_post_meta($campaign, 'mtbf_sale_badge_image_width', true),
		'campaign_show_cart_contents' => get_post_meta($campaign, 'mtbf_show_cart_contents', true),
	);
	return $campaign_details;
}

function mtbf_obtain_additional_products($request) {
	$category = $request->get_param("category");
	$args = array(
		'category' => array( $category ),
		'orderby'  => 'name',
	);
	$products = wc_get_products( $args );
	$additional_products = [];
	foreach ($products as $product) {
		$images = [];
		$main_image['src'] = wp_get_attachment_url($product->get_image_id());
		$images[0] = $main_image;
		foreach ($product->get_gallery_image_ids() as $image_id) {
			array_push($images, wp_get_attachment_image_src($image_id));
		}
		if ($product->get_meta('mtbf_show_in_bf')) {
			$array = array(
				'id' => $product->get_id(),
				'name' => $product->get_name(),
				'slug' => $product->get_slug(),
				'permalink' => get_permalink($product->get_id()),
				'attributes' => $product->get_attributes(),
				'average_rating' => $product->get_average_rating(),
				'backorders' => $product->get_backorders(),
				'catalog_visibility' => $product->get_catalog_visibility(),
				'categories' => get_the_terms( $product->get_id(), 'product_cat' ),
				'cross_sell_ids' => $product->get_cross_sell_ids(),
				'date_created' => $product->get_date_created(),
				'date_modified' => $product->get_date_modified(),
				'date_on_sale_from' => $product->get_date_on_sale_from(),
				'date_on_sale_to' => $product->get_date_on_sale_to(),
				'default_attributes' => $product->get_default_attributes(),
				'description' => $product->get_description(),
				'dimensions' => $product->get_dimensions(),
				'download_expiry' => $product->get_download_expiry(),
				'download_limit' => $product->get_download_limit(),
				'downloadable' => $product->get_downloadable(),
				'downloads' => $product->get_downloads(),
				'featured' => $product->get_featured(),
				'images' =>  $images,
				'manage_stock' => $product->get_manage_stock(),
				'menu_order' => $product->get_menu_order(),
				'on_sale' => $product->is_on_sale(),
				'parent_id' => $product->get_parent_id(),
				'price' => $product->get_price(),
				'price_html' => $product->get_price_html(),
				'purchase_note' => $product->get_purchase_note(),
				'rating_count' => $product->get_review_count(),
				'regular_price' => $product->get_regular_price(),
				'reviews_allowed' => $product->get_reviews_allowed(),
				'sale_price' => $product->get_sale_price(),
				'shipping_class' => $product->get_shipping_class(),
				'shipping_class_id' => $product->get_shipping_class_id(),
				'short_description' => $product->get_short_description(),
				'sku' => $product->get_sku(),
				'sold_individually' => $product->get_sold_individually(),
				'status' => $product->get_status(),
				'stock_quantity' => $product->get_stock_quantity(),
				'stock_status' => $product->get_stock_status(),
				'tags' => $product->get_tag_ids(),
				'tax_class' => $product->get_tax_class(),
				'tax_status' => $product->get_tax_status(),
				'total_sales' => $product->get_total_sales(),
				'type' => $product->get_type(),
				'upsell_ids' => $product->get_upsell_ids(),
				'varations' => $product->get_children(),
				'virtual' => $product->get_virtual(),
				'weight' => $product->get_weight(),
			);
			$additional_products['ap'.$product->get_id()] = $array;
		}
	}
	return $additional_products;
}

function mtbf_obtain_hardcoded_strings() {
	$hardcoded_strings = array(
		'back_to_website_label' => esc_html__('Back to Website', 'mtbf'),
		'my_cart_label' => esc_html__('My Cart', 'mtbf'),
		'my_account_label' => esc_html__('My Account', 'mtbf'),
		'shop_by_category_label' => esc_html__('Shop by Category', 'mtbf'),
		'countdown_days_label' => esc_html__('days', 'mtbf'),
		'countdown_hours_label' => esc_html__('hours', 'mtbf'),
		'countdown_minutes_label' => esc_html__('minutes', 'mtbf'),
		'countdown_seconds_label' => esc_html__('seconds', 'mtbf'),
		'items_label' => esc_html__('Items -', 'mtbf'),
		'total_price_label' => esc_html__('Total Price', 'mtbf'),
		'category_label' => esc_html__('Category', 'mtbf'),
		'out_of_stock_label' => esc_html__('Out of Stock', 'mtbf'),
		'in_stock_label' => esc_html__('In Stock', 'mtbf'),
		'limited_stock_label' => esc_html__('Limited Stock', 'mtbf'),
		'sale_badge_label' => esc_html__('On Sale', 'mtbf'),
		'product_name_label' => esc_html__('Product Name', 'mtbf'),
		'product_regular_price_label' => esc_html__('Regular Price', 'mtbf'),
		'product_sale_price_label' => esc_html__('Sale Price', 'mtbf'),
		'view_cart_label' => esc_html__('View Cart', 'mtbf'),
		'add_to_cart_label' => esc_html__('Add to cart', 'mtbf'),
		'see_more_products_label' => esc_html__('See More Products', 'mtbf'),
		'campaign_title' => esc_html__('Campaign', 'mtbf'),
		'campaign_ended_label' => esc_html__('Sale ended !', 'mtbf'),
		'campaign_start_soon_label' => esc_html__('Sale starts in:', 'mtbf'),
	);
	return $hardcoded_strings;
}

$plugin_dir = plugin_dir_path( __FILE__ );

function mtbf_scripts() {
        wp_enqueue_script('sticky-sidebar', plugin_dir_url(__FILE__) . 'js/sticky-sidebar.js', array('jquery'));
        wp_enqueue_style('mtbf-frontend-custom', plugin_dir_url(__FILE__) . 'css/mtbf-frontend-custom.css', false);
        wp_enqueue_style('mtbf-frontend-campaign', plugin_dir_url(__FILE__) . 'css/mtbf-frontend-campaign.css', false);
        wp_enqueue_script('jquery-countdown', plugin_dir_url(__FILE__) . 'js/jquery-countdown.js', array('jquery'));
        wp_enqueue_script('bf-custom', plugin_dir_url(__FILE__) . 'js/bf-custom.js', array('jquery','mtbf-modal-js'));
}
add_action( 'wp_enqueue_scripts', 'mtbf_scripts' );

require_once('inc/shortcodes.php');

function mtbf_product_countdown( ) {
		$active_campaign = get_option('mtbf_campaign_active');
	    $dateEnd = date("Y/m/d H:i:s", strtotime(get_post_meta($active_campaign, 'mtbf_datetime_end_date', true) . ' ' . get_post_meta($active_campaign, 'mtbf_datetime_end_time', true)));
	    ?>
	        <div
				class="mtbf-campaign-remaining-time product large-12 medium-12 small-12"
				style="background: <?php echo get_post_meta($active_campaign, 'mtbf_body_bg_color', true) ?> url(<?php echo get_post_meta($active_campaign, 'mtbf_body_bg', true) ?>) top center/100% auto no-repeat;"
			>
				<div>
					<p><?= __(get_option('mtbf_ends_in_text')) ?></p><?= do_shortcode('[mt-countdown date="' . esc_attr($dateEnd) . '"]') ?>
					<a target="_blank" href="<?php echo get_site_url().'/black-friday/'; ?>" class="mtbf-link"><?= __("Vezi toate promoțiile Black Friday") ?></a>
				</div>
	        </div>
	    <?php
}
add_action('woocommerce_after_add_to_cart_form', 'mtbf_product_countdown', 31);

add_action('woocommerce_process_product_meta', 'mtbf_save_option');

function mtbf_save_option($post_id) {
	$show_in_bf_value = isset($_POST['mtbf_show_in_bf']) ? $_POST['mtbf_show_in_bf'] : '0';
	update_post_meta($post_id, 'mtbf_show_in_bf', $show_in_bf_value);
}


/**
||-> CMB METABOXES
*/

require_once ('inc/cmb2/init.php');



/**
||-> Function: mtbf_enqueue_admin_scripts()
*/
if (!function_exists('mtbf_enqueue_admin_scripts')) {
	function mtbf_enqueue_admin_scripts( $hook ) {
	    // CSS
	    wp_register_style( 'mtbf-admin-style',  plugin_dir_url( __FILE__ ) . 'css/mtbf-admin-style.css' );
	    wp_enqueue_style( 'mtbf-admin-style' );
	}
	add_action('admin_enqueue_scripts', 'mtbf_enqueue_admin_scripts');
}

// LOAD METABOXES
require_once('inc/metaboxes.php');
// LOAD POST TYPES
require_once('inc/post-types.php');





/**
||-> Function: LOAD PLUGIN TEXTDOMAIN
*/
function mtbf_load_textdomain(){
    $domain = 'mtbf';
    $locale = apply_filters( 'plugin_locale', get_locale(), $domain );
    load_textdomain( $domain, trailingslashit( WP_LANG_DIR ) . esc_html($domain) . '/' . esc_html($domain) . '-' . esc_html($locale) . '.pot' );
    load_plugin_textdomain( $domain, FALSE, basename( plugin_dir_path( dirname( __FILE__ ) ) ) . '/languages/' );
}
add_action( 'plugins_loaded', 'mtbf_load_textdomain' );

// create custom plugin settings menu
if (!function_exists('mtbf_create_menu')) {
	function mtbf_create_menu() {
	    add_submenu_page(
	        'edit.php?post_type=mtbf',
	        esc_html__('MTBF Settings', 'mtbf'),
	        esc_html__('MTBF Settings', 'mtbf'),
	        'manage_options',
	        'mtbf_settings',
	        'mtbf_settings_page'
	    );
	}
	add_action('admin_menu', 'mtbf_create_menu');
}

// REGISTER MTBF SETTINGS PAGE
if (!function_exists('mtbf_register_page')) {
	function mtbf_register_page() {
		//register our settings
		register_setting( 'mtbf_settings', 'mtbf_consumer_key' );
		register_setting( 'mtbf_settings', 'mtbf_consumer_secret' );
		register_setting( 'mtbf_settings', 'mtbf_campaign_active' );
		register_setting( 'mtbf_settings', 'mtbf_products_type' );
		register_setting( 'mtbf_settings', 'mtbf_ends_in_text' );
		register_setting( 'mtbf_settings', 'mtbf_shop_by_category_text' );
		register_setting( 'mtbf_settings', 'mtbf_see_more_products_text' );
		register_setting( 'mtbf_settings', 'mtbf_video_coming_soon' );
		register_setting( 'mtbf_settings', 'mtbf_excluded_categories' );
		register_setting( 'mtbf_settings', 'mtbf_enable_sidebar' );
		register_setting( 'mtbf_settings', 'mtbf_enable_sticky_navigation' );
	}
	add_action( 'admin_init', 'mtbf_register_page' );
}



// Black Friday & Cyber Monday Settings
if (!function_exists('mtbf_settings_page')) {
	function mtbf_settings_page() {
	?>
		<div class="wrap">
			<h1>
				<?php echo esc_html__('Black Friday & Cyber Monday Settings', 'mtbf'); ?>
			</h1>
			<div class="notice notice-success is-dismissible">
				<p>
					<strong>
						<?php echo esc_html__('Note: ', 'mtbf'); ?>
					</strong>
					<?php echo esc_html__('These options only apply to the Black Friday Page Template.', 'mtbf'); ?>
				</p>
				<button type="button" class="notice-dismiss">
					<span class="screen-reader-text">
						<?php echo esc_html__('Dismiss this notice.', 'mtbf'); ?>
					</span>
				</button>
			</div>
			<form method="post" action="options.php">
				<?php settings_fields( 'mtbf_settings' ); ?>
				<?php do_settings_sections( 'mtbf_settings' ); ?>
				<table class="form-table">
					<tr valign="top">
						<th scope="row">
							<h2>
								<?php echo esc_html__('REST API Settings', 'mtbf'); ?>
							</h2>
						</th>
					</tr>
					<tr valign="top">
						<th scope="row">
							<?php echo esc_html__('Consumer Key', 'mtbf'); ?>
							<span style='color: red'> <?php echo esc_html__('*', 'mtbf'); ?> </span>
						</th>
						<td>
							<input required type="text" name="mtbf_consumer_key" value="<?php echo esc_attr( get_option('mtbf_consumer_key') ); ?>" />
							<p>
								<i>
									<?php echo esc_html__('Consumer Key generated in the Woocommerce REST API settings.', 'mtbf'); ?>
								</i>
							</p>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<?php echo esc_html__('Consumer Secret', 'mtbf'); ?>
							<span style='color: red'> <?php echo esc_html__('*', 'mtbf'); ?> </span>
						</th>
						<td>
							<input required type="text" name="mtbf_consumer_secret" value="<?php echo esc_attr( get_option('mtbf_consumer_secret') ); ?>" />
							<p>
								<i>
									<?php echo esc_html__('Consumer Secret generated in the Woocommerce REST API settings.', 'mtbf'); ?>
								</i>
							</p>
						</td>
					</tr>
					<!-- SELECT CAMPAIGN DROPDOWN -->
					<tr valign="top">
						<th scope="row">
							<h2>
								<?php echo esc_html__('Campaign', 'mtbf'); ?>
							</h2>
						</th>
					</tr>
					<tr valign="top">
						<th scope="row">
							<?php echo esc_html__('Active Campaign', 'mtbf'); ?>
						</th>
						<td>
							<select name="mtbf_campaign_active" id="mtbf_campaign_active" class="mtbf_campaign_active">
								<?php 
									$args_posts = array(
										'posts_per_page'        => -1,
										'post_type'             => 'mtbf',
										'post_status'           => 'publish' 
									);
									$mtbfs = get_posts($args_posts); 
								?>
								<option value="none">
									<?php esc_html_e('-Select Campaign-', 'mtbf'); ?>
								</option>
								<?php if ($mtbfs) { ?>
									<?php foreach ($mtbfs as $mtbf){ ?>
										<option value="<?php echo esc_attr($mtbf->ID); ?>"
											<?php if(get_option('mtbf_campaign_active') == $mtbf->ID){echo esc_html_e('selected', 'mtbf'); }; ?>>
											<?php echo esc_html($mtbf->post_title); ?>
										</option>
									<?php } ?>
								<?php } ?>
							</select>
							<p>
								<i>
									<?php echo esc_html__('The page template will show products only if a campaign is set on this dropdown. If no Campaigns are on the dropdown, add one from MT Black Friday.', 'mtbf'); ?>
								</i>
							</p>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<h2>
								<?php echo esc_html__('Custom Settings', 'mtbf'); ?>
							</h2>
						</th>
					</tr>
					<!-- Enable sticky navigation -->
					<tr valign="top">
						<th scope="row">
							<?php echo esc_html__('Enable Sticky Navigation', 'mtbf'); ?>
						</th>
						<td>
							<select name="mtbf_enable_sticky_navigation" id="mtbf_enable_sticky_navigation" class="mtbf_enable_sticky_navigation">
								<option
									value="disabled"
									<?php if(get_option('mtbf_enable_sticky_navigation') == 'disabled'){echo esc_html_e('selected', 'mtbf'); }; ?>
								>
									<?php esc_html_e('Disabled', 'mtbf'); ?>
								</option>
								<option
									value="enabled"
									<?php if(get_option('mtbf_enable_sticky_navigation') == 'enabled'){echo esc_html_e('selected', 'mtbf'); }; ?>
								>
									<?php esc_html_e('Enabled', 'mtbf'); ?>
								</option>
							</select>
							<p>
								<i>
									<?php echo esc_html__('This setting is available for ALL Templates.', 'mtbf'); ?>
								</i>
							</p>
						</td>
					</tr>
					<!-- Enable Sidebar -->
					<tr valign="top">
						<th scope="row">
							<?php echo esc_html__('Enable Sidebar', 'mtbf'); ?>
						</th>
						<td>
							<select name="mtbf_enable_sidebar" id="mtbf_enable_sidebar" class="mtbf_enable_sidebar">
								<option
									value="enabled"
									<?php if(get_option('mtbf_enable_sidebar') == 'enabled'){echo esc_html_e('selected', 'mtbf'); }; ?>
								>
									<?php esc_html_e('Visible', 'mtbf'); ?>
								</option>
								<option
									value="disabled"
									<?php if(get_option('mtbf_enable_sidebar') == 'disabled'){echo esc_html_e('selected', 'mtbf'); }; ?>
								>
									<?php esc_html_e('Hide', 'mtbf'); ?>
								</option>
							</select>
							<p>
								<i>
									<?php echo esc_html__('This setting is available for ALL Templates.', 'mtbf'); ?>
								</i>
							</p>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<h2>
								<?php echo esc_html__('Preferences', 'mtbf'); ?>
							</h2>
						</th>
					</tr>
					<!-- SELECT PRODUCTS TO SHOW -->
					<tr valign="top">
						<th scope="row">
							<?php echo esc_html__('Select Products to Show', 'mtbf'); ?>
						</th>
						<td>
							<select name="mtbf_products_type" id="mtbf_products_type" class="mtbf_products_type">
								<option value="none">
									<?php esc_html_e('-Select Option-', 'mtbf'); ?>
								</option>
								<option
									value="sale_products"
									<?php if(get_option('mtbf_products_type') == 'sale_products'){echo esc_html_e('selected', 'mtbf'); }; ?>
								>
									<?php esc_html_e('Products On-Sale', 'mtbf'); ?>
								</option>
								<option
									value="all_products"
									<?php if(get_option('mtbf_products_type') == 'all_products'){echo esc_html_e('selected', 'mtbf'); }; ?>
								>
									<?php esc_html_e('All Products', 'mtbf'); ?>
								</option>
							</select>
							<p>
								<i>
									<?php echo esc_html__('Select want kind of products needs to be listed on the Black Friday Page Template.', 'mtbf'); ?>
								</i>
							</p>
						</td>
					</tr>
					<!-- ENDS IN TEXT -->
					<tr valign="top">
						<th scope="row">
							<?php echo esc_html__('Campaign Ends In Text', 'mtbf'); ?>
						</th>
						<td>
							<input type="text" name="mtbf_ends_in_text" value="<?php echo esc_attr( get_option('mtbf_ends_in_text') ); ?>" />
							<p>
								<i>
									<?php echo esc_html__('When the Campaign is active, this text will be shown before the time countdown.', 'mtbf'); ?>
								</i>
							</p>
						</td>
					</tr>
					<!-- SHOP BY CATEGORY TEXT -->
					<tr valign="top">
						<th scope="row"><?php echo esc_html__('Shop by category text', 'mtbf'); ?></th>
						<td>
							<input type="text" name="mtbf_shop_by_category_text" value="<?php echo esc_attr( get_option('mtbf_shop_by_category_text') ); ?>" />
							<p>
								<i>
									<?php echo esc_html__('When the Campaign is active, this text will be shown before category list (left side).', 'mtbf'); ?>
								</i>
							</p>
						</td>
					</tr>
					<!-- SEE MORE PRODUCTS TEXT -->
					<tr valign="top">
						<th scope="row"><?php echo esc_html__('See more products link text', 'mtbf'); ?></th>
						<td>
							<input type="text" name="mtbf_see_more_products_text" value="<?php echo esc_attr( get_option('mtbf_see_more_products_text') ); ?>" />
							<p>
								<i>
									<?php echo esc_html__('When the Campaign is active, this text will be shown at the end of the products from each category.', 'mtbf'); ?>
								</i>
							</p>
						</td>
					</tr>
					<!-- Video URL -->
					<tr valign="top">
						<th scope="row">
							<?php echo esc_html__('Video URL', 'mtbf'); ?>
						</th>
						<td>
							<input type="text" name="mtbf_video_coming_soon" value="<?php echo esc_attr( get_option('mtbf_video_coming_soon') ); ?>" />
							<p>
								<i>
									<?php echo esc_html__('Can only be used for Coming Soon Template', 'mtbf'); ?>
								</i>
							</p>
						</td>
					</tr>
					<!-- Exclude Categories -->
					<tr valign="top">
						<th scope="row">
							<?php echo esc_html__('Exclude Categories', 'mtbf'); ?>
						</th>
						<td>
							<?php $selected = ''; ?>
							<?php $mtbf_excluded_categories = get_option('mtbf_excluded_categories'); ?>
							<select multiple="multiple" name="mtbf_excluded_categories[]" size="10">
								<?php if (isset($mtbf_excluded_categories) && !is_null($mtbf_excluded_categories)) { ?>
									<?php $selected = in_array( "0", $mtbf_excluded_categories ) ? ' selected="selected" ' : ''; ?>
								<?php } ?>
								<option
									value="0"
									<?php echo $selected; ?>
								>
									<?php echo esc_html__('-No Need to Exclude Categories-', 'mtbf'); ?>
								</option>
								<?php 
								$categories = get_terms( 
									'product_cat', 
									array( 
										'parent' => 0, 
										'orderby' => 'slug',
										'hide_empty' => 1,
									)
								);
								foreach ($categories as $category) { ?>
									<?php if (isset($mtbf_excluded_categories) && !is_null($mtbf_excluded_categories)) { ?>
										<?php $selected = in_array( $category->term_id, $mtbf_excluded_categories ) ? ' selected="selected" ' : ''; ?>
									<?php } ?>
									<option
										value="<?php echo $category->term_id; ?>"
										<?php echo $selected; ?>
									>
										<?php echo $category->name; ?>
									</option>
								<?php } //endforeach ?>
							</select>
							<p>
								<i>
									<?php echo esc_html__('The selected categories will be excluded from the campaign.', 'mtbf'); ?>
								</i>
							</p>
						</td>
					</tr>
				</table>
				<?php submit_button(); ?>
			</form>
		</div>
	<?php } ?>
<?php }